import { createRouter, createWebHistory, RouteRecordRaw } from 'vue-router'

const routes: RouteRecordRaw[] = [
  { path: '/', redirect: '/shows' },
  {
    path: '/shows',
    children: [
      {
        path: '/shows',
        name: 'shows',
        component: () => import('@/Pages/MyShows.vue'),
      },
      {
        path: ':showId',
        name: 'show',
        component: () => import('@/Pages/Show.vue'),
        redirect: (to) => ({ path: `/shows/${to.params.showId}/episodes` }),
        children: [
          {
            path: 'basic-data',
            name: 'show-basic-data',
            component: () => import('@/Pages/ShowBasicData.vue'),
          },
          {
            path: 'episodes',
            name: 'show-episodes',
            component: () => import('@/Pages/ShowEpisodes.vue'),
          },
          {
            path: 'episodes/:episodeId',
            name: 'show-episode',
            component: () => import('@/Pages/ShowEpisode.vue'),
            redirect: (to) => ({
              path: `/shows/${to.params.showId}/episodes/${to.params.episodeId}/details`,
            }),
            children: [
              {
                path: 'details',
                name: 'show-episode-details',
                component: () => import('@/Pages/ShowEpisodeDetails.vue'),
              },
            ],
          },
        ],
      },
    ],
  },
  {
    path: '/profiles',
    children: [
      {
        path: '/profiles',
        name: 'profiles',
        component: () => import('@/Pages/ProfileList.vue'),
      },
      {
        path: ':profileId',
        name: 'profile',
        component: () => import('@/Pages/Profile.vue'),
        redirect: (to) => ({ path: `/profiles/${to.params.profileId}/details` }),
        children: [
          {
            path: 'details',
            name: 'profile-details',
            component: () => import('@/Pages/ProfileDetails.vue'),
          },
        ],
      },
    ],
  },
  { path: '/calendar', name: 'calendar', component: () => import('@/Pages/Calendar.vue') },
  { path: '/credits', name: 'credits', component: () => import('@/Pages/Credits.vue') },
]

export default createRouter({
  history: createWebHistory(),
  routes,
})
