import {
  APIListPaginated,
  APIRemove,
  APIRetrieve,
  APIUpdate,
  createExtendableAPI,
} from '@rokoli/bnb/drf'
import { defineStore } from 'pinia'

import { createSteeringURL } from '@/api'
import { components } from '@/steering-types'
import { steeringAuthInit } from '@/stores/auth'
import { KeysFrom, Host } from '@/types'

type ReadonlyAttrs = KeysFrom<Host, 'id'>
type HostUpdateData = Omit<Host, ReadonlyAttrs>
type HostPartialUpdateData = components['schemas']['PatchedHost']

export const useHostStore = defineStore('hosts', () => {
  const endpoint = createSteeringURL.prefix('hosts')
  const { api, base } = createExtendableAPI<Host>(endpoint, steeringAuthInit)
  return {
    ...base,
    ...APIListPaginated(api),
    ...APIRetrieve(api),
    ...APIUpdate<Host, HostUpdateData, HostPartialUpdateData>(api),
    ...APIRemove(api),
  }
})
